@@ -1,12 +1,13 @@
+
+
 class SepConventions(object):
 
-    # Separators used in names, external and internal
+    # Separators used in names
 
-    def __init__(self, **kwargs):
+    def __init__(self,**kwargs):
         super().__init__(**kwargs)
-        self.SEP = SepConventions.sep()
+        self.SEP   = SepConventions.sep()
         self.TILDE = SepConventions.tilde()
-        self.PIPE = SepConventions.pipe()
 
     @staticmethod
     def sep():
@@ -14,8 +15,4 @@ class SepConventions(object):
 
     @staticmethod
     def tilde():
-        return '~'
-
-    @staticmethod
-    def pipe():
-        return '|'
+        return '~'
\ No newline at end of file
